"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const debug_1 = tslib_1.__importDefault(require("debug"));
const kleur_1 = tslib_1.__importDefault(require("kleur"));
const path_1 = require("path");
const cli_1 = require("./cli");
const fs_1 = require("./fs");
const help = tslib_1.__importStar(require("./help"));
const options_1 = require("./options");
const prompt_1 = require("./prompt");
const template_1 = require("./template");
const debug = debug_1.default('@capacitor/create-plugin');
process.on('unhandledRejection', error => {
    process.stderr.write(`ERR: ${error}\n`);
    process.exit(1);
});
exports.run = async () => {
    if (process.argv.find(arg => ['-h', '-?', '--help'].includes(arg))) {
        help.run();
        process.exit();
    }
    const options = options_1.getOptions();
    debug('options from command-line: %O', options);
    if (Object.values(options).includes(undefined)) {
        if (cli_1.isTTY) {
            debug(`Missing/invalid options. Prompting for user input...`);
        }
        else {
            process.stderr.write(`ERR: Refusing to prompt for missing/invalid options in non-TTY environment.\n` +
                `See ${kleur_1.default.bold('--help')}. Run with ${kleur_1.default.bold('--verbose')} for more context.\n`);
            process.exit(1);
        }
    }
    const details = await prompt_1.gatherDetails(options);
    const dir = path_1.resolve(process.cwd(), details.dir);
    if (await fs_1.exists(dir)) {
        process.stderr.write(`ERR: Not overwriting existing directory: ${kleur_1.default.bold(details.dir)}`);
        process.exit(1);
    }
    await template_1.extractTemplate(dir, details);
    const tada = cli_1.emoji('🎉', '*');
    process.stdout.write(`
${kleur_1.default.bold(`${tada} Capacitor plugin generated! ${tada}`)}

Next steps:
  - ${kleur_1.default.bold(`cd ${details.dir}/`)}
  - install dependencies (e.g. w/ ${kleur_1.default.bold('npm install')})
`);
};
